@@ -50,7 +50,7 @@ let sexp_of_float_mat mat =
 let sexp_of_float32_mat (mat : float32_mat) = sexp_of_float_mat mat
 let sexp_of_float64_mat (mat : float64_mat) = sexp_of_float_mat mat
 let sexp_of_mat (mat : mat) = sexp_of_float_mat mat
-let bigstring_sexp_grammar : Sexplib0.Sexp.Private.Raw_grammar.t = Inline (Atom String)
+let bigstring_sexp_grammar : bigstring Sexplib0.Sexp_grammar.t = { untyped = String }
 
 let bigstring_of_sexp sexp =
   match sexp with
@@ -87,11 +87,7 @@ let empty_float64_vec = create_float64_vec 0
 let float32_vec_of_sexp = float_vec_of_sexp empty_float32_vec create_float32_vec
 let float64_vec_of_sexp = float_vec_of_sexp empty_float64_vec create_float64_vec
 let vec_of_sexp = float_vec_of_sexp empty_float64_vec create_float64_vec
-
-let vec_sexp_grammar : Sexplib0.Sexp.Private.Raw_grammar.t =
-  Inline (List [ Many (Atom Float) ])
-;;
-
+let vec_sexp_grammar : _ Sexplib0.Sexp_grammar.t = { untyped = List (Many Float) }
 let float32_vec_sexp_grammar = vec_sexp_grammar
 let float64_vec_sexp_grammar = vec_sexp_grammar
 
@@ -115,8 +111,7 @@ let float_mat_of_sexp create_float_mat sexp =
           | h :: t ->
             vec.{row} <- float_of_sexp h;
             if row = m
-            then
-              if col = n then check_too_much_data sexp t res else loop_cols (col + 1) t
+            then if col = n then check_too_much_data sexp t res else loop_cols (col + 1) t
             else loop_rows (row + 1) t
         in
         loop_rows 1 data
@@ -132,8 +127,8 @@ let float32_mat_of_sexp = float_mat_of_sexp create_float32_mat
 let float64_mat_of_sexp = float_mat_of_sexp create_float64_mat
 let mat_of_sexp = float_mat_of_sexp create_float64_mat
 
-let mat_sexp_grammar : Sexplib0.Sexp.Private.Raw_grammar.t =
-  Inline (List [ One (Atom Int); One (Atom Int); Many (Atom Float) ])
+let mat_sexp_grammar : _ Sexplib0.Sexp_grammar.t =
+  { untyped = List (Cons (Integer, Cons (Integer, Many Float))) }
 ;;
 
 let float32_mat_sexp_grammar = mat_sexp_grammar
