@@ -14,12 +14,14 @@ type bigstring = (char, int8_unsigned_elt, c_layout) Array1.t
 include (
   Sexplib.Sexp :
     module type of struct
-    include Sexplib.Sexp
-  end
-  with type t := t)
+      include Sexplib.Sexp
+    end
+    with type t := t)
 
 include Private
 
+let t_sexp_grammar = Conv.sexp_t_sexp_grammar
+
 (* Output of S-expressions to I/O-channels *)
 
 let with_new_buffer oc f =
@@ -153,8 +155,8 @@ let sexp_conversion_error_message ?containing_sexp ?location ?invalid_sexp () ~e
           | None -> []
           | Some x -> [ Atom x ])
        ; [ (match exn with
-             | Failure x -> Atom x
-             | _ -> Conv.sexp_of_exn exn)
+            | Failure x -> Atom x
+            | _ -> Conv.sexp_of_exn exn)
          ]
        ; (match invalid_sexp with
           | None -> []
@@ -298,8 +300,7 @@ let () =
             [ List [ Atom "err_msg"; Atom pe.err_msg ]
             ; List [ Atom "text_line"; Conv.sexp_of_int ppos.Parse_pos.text_line ]
             ; List [ Atom "text_char"; Conv.sexp_of_int ppos.Parse_pos.text_char ]
-            ; List
-                [ Atom "global_offset"; Conv.sexp_of_int ppos.Parse_pos.global_offset ]
+            ; List [ Atom "global_offset"; Conv.sexp_of_int ppos.Parse_pos.global_offset ]
             ; List [ Atom "buf_pos"; Conv.sexp_of_int ppos.Parse_pos.buf_pos ]
             ]
         ]
@@ -319,6 +320,9 @@ module Parser_output : sig
 
   module Bare_sexp : T with type output = Type.t
   module Annotated_sexp : T with type output = Annot.t
+
+  val annotate_sexp : Type.t -> Parsexp.Positions.Iterator.t -> Annot.t
+  val annotate_sexp_list : Type.t list -> Parsexp.Positions.Iterator.t -> Annot.t list
 end = struct
   module type T = sig
     module Impl : Parsexp.Eager_parser
@@ -373,20 +377,20 @@ end = struct
 end
 
 module Make_parser (T : sig
-    include Parser_output.T
+  include Parser_output.T
 
-    type input
+  type input
 
-    val length : input -> int
+  val length : input -> int
 
-    val unsafe_feed_loop
-      :  Impl.State.t
-      -> Impl.Stack.t
-      -> input
-      -> max_pos:int
-      -> pos:int
-      -> Impl.Stack.t
-  end) : sig
+  val unsafe_feed_loop
+    :  Impl.State.t
+    -> Impl.Stack.t
+    -> input
+    -> max_pos:int
+    -> pos:int
+    -> Impl.Stack.t
+end) : sig
   val parse
     :  ?parse_pos:Parse_pos.t
     -> ?len:int
@@ -433,10 +437,7 @@ end = struct
       let next_pos = pos + (offset - previous_offset) in
       Done (result, parse_pos_of_state state next_pos)
     | exception Parsexp.Parse_error.Parse_error err ->
-      handle_parsexp_error
-        state
-        (pos + (T.Impl.State.offset state - previous_offset))
-        err
+      handle_parsexp_error state (pos + (T.Impl.State.offset state - previous_offset)) err
 
   and mk_cont_state state stack =
     let parse_fun =
@@ -458,7 +459,9 @@ end = struct
       ( { Parsexp.Positions.line = text_line; col = text_char; offset = global_offset }
       , buf_pos )
     in
-    let state = T.Impl.State.create ~pos ~no_sexp_is_error:false T.raise_found in
+    let state =
+      T.Impl.State.create ~pos ~reraise_notrace:true ~no_sexp_is_error:false T.raise_found
+    in
     let stack = T.Impl.Stack.empty in
     let len =
       match len with
@@ -471,75 +474,75 @@ end
 [@@inline always]
 
 module String_single_sexp = Make_parser (struct
-    include Parser_output.Bare_sexp
+  include Parser_output.Bare_sexp
 
-    type input = string
+  type input = string
 
-    let length = String.length
+  let length = String.length
 
-    let rec unsafe_feed_loop state stack str ~max_pos ~pos =
-      if pos <= max_pos
-      then (
-        let stack = Impl.feed state (String.unsafe_get str pos) stack in
-        unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
-      else stack
-    ;;
-  end)
+  let rec unsafe_feed_loop state stack str ~max_pos ~pos =
+    if pos <= max_pos
+    then (
+      let stack = Impl.feed state (String.unsafe_get str pos) stack in
+      unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
+    else stack
+  ;;
+end)
 
 let parse_str = String_single_sexp.parse
 let parse = String_single_sexp.parse
 
 module String_single_annot = Make_parser (struct
-    include Parser_output.Annotated_sexp
+  include Parser_output.Annotated_sexp
 
-    type input = string
+  type input = string
 
-    let length = String.length
+  let length = String.length
 
-    let rec unsafe_feed_loop state stack str ~max_pos ~pos =
-      if pos <= max_pos
-      then (
-        let stack = Impl.feed state (String.unsafe_get str pos) stack in
-        unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
-      else stack
-    ;;
-  end)
+  let rec unsafe_feed_loop state stack str ~max_pos ~pos =
+    if pos <= max_pos
+    then (
+      let stack = Impl.feed state (String.unsafe_get str pos) stack in
+      unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
+    else stack
+  ;;
+end)
 
 let parse_str_annot = String_single_annot.parse
 
 module Bigstring_single_sexp = Make_parser (struct
-    include Parser_output.Bare_sexp
+  include Parser_output.Bare_sexp
 
-    type input = bigstring
+  type input = bigstring
 
-    let length = Array1.dim
+  let length = Array1.dim
 
-    let rec unsafe_feed_loop state stack (str : input) ~max_pos ~pos =
-      if pos <= max_pos
-      then (
-        let stack = Impl.feed state (Array1.unsafe_get str pos) stack in
-        unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
-      else stack
-    ;;
-  end)
+  let rec unsafe_feed_loop state stack (str : input) ~max_pos ~pos =
+    if pos <= max_pos
+    then (
+      let stack = Impl.feed state (Array1.unsafe_get str pos) stack in
+      unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
+    else stack
+  ;;
+end)
 
 let parse_bigstring = Bigstring_single_sexp.parse
 
 module Bigstring_single_annot = Make_parser (struct
-    include Parser_output.Annotated_sexp
+  include Parser_output.Annotated_sexp
 
-    type input = bigstring
+  type input = bigstring
 
-    let length = Array1.dim
+  let length = Array1.dim
 
-    let rec unsafe_feed_loop state stack (str : input) ~max_pos ~pos =
-      if pos <= max_pos
-      then (
-        let stack = Impl.feed state (Array1.unsafe_get str pos) stack in
-        unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
-      else stack
-    ;;
-  end)
+  let rec unsafe_feed_loop state stack (str : input) ~max_pos ~pos =
+    if pos <= max_pos
+    then (
+      let stack = Impl.feed state (Array1.unsafe_get str pos) stack in
+      unsafe_feed_loop state stack str ~max_pos ~pos:(pos + 1))
+    else stack
+  ;;
+end)
 
 let parse_bigstring_annot = Bigstring_single_annot.parse
 
@@ -635,15 +638,20 @@ let of_string_bigstring loc my_parse ws_buf get_len get_sub str =
          (sprintf
             "Sexplib.Sexp.%s: got multiple S-expressions where only one was expected."
             loc)
-     | Cont (Cont_state.Parsing_toplevel_whitespace, _) -> sexp
-     | Cont (_, _) ->
-       (* not using [feed_end_of_input] here means "a b" will end up here and not in
-          "multiple S-expressions" branch, but it doesn't matter that much *)
-       failwith
-         (sprintf
-            "Sexplib.Sexp.%s: S-expression followed by data at position %d..."
-            loc
-            parse_pos.buf_pos))
+     | Cont (_, this_parse) ->
+       (match feed_end_of_input ~this_parse ~ws_buf with
+        | Ok _ ->
+          failwith
+            (sprintf
+               "Sexplib.Sexp.%s: got multiple S-expressions where only one was expected."
+               loc)
+        | Error Cont_state.Parsing_toplevel_whitespace -> sexp
+        | Error _ ->
+          failwith
+            (sprintf
+               "Sexplib.Sexp.%s: S-expression followed by data at position %d..."
+               loc
+               parse_pos.buf_pos)))
   | Cont (_, this_parse) ->
     (match feed_end_of_input ~this_parse ~ws_buf with
      | Ok sexp -> sexp
@@ -657,9 +665,8 @@ let of_string_bigstring loc my_parse ws_buf get_len get_sub str =
             (get_sub str 0 (get_len str))))
 ;;
 
-let of_string str =
-  of_string_bigstring "of_string" parse " " String.length String.sub str
-;;
+let of_string str = of_string_bigstring "of_string" parse " " String.length String.sub str
+let of_string_many str = Parsexp.Many.parse_string_exn str
 
 let get_bstr_sub_str bstr pos len =
   let str = Bytes.create len in
@@ -773,6 +780,11 @@ module Annotated = struct
     of_string_bigstring "Annotated.of_string" parse " " String.length String.sub str
   ;;
 
+  let of_string_many str =
+    let sexps, positions = Parsexp.Many_and_positions.parse_string_exn str in
+    Parser_output.annotate_sexp_list sexps (Parsexp.Positions.Iterator.create positions)
+  ;;
+
   let of_bigstring bstr =
     of_string_bigstring
       "Annotated.of_bigstring"
@@ -888,6 +900,11 @@ let gen_of_string_conv_exn of_string str f =
 let of_string_conv_exn str f = gen_of_string_conv_exn of_string str f
 let of_bigstring_conv_exn bstr f = gen_of_string_conv_exn of_bigstring bstr f
 
+let of_string_many_conv_exn str f =
+  let sexps = of_string_many str in
+  List.map (fun sexp -> gen_of_string_conv_exn (fun x -> x) sexp f) sexps
+;;
+
 (* Utilities for automated type conversions *)
 
 let unit = List []
