@@ -117,11 +117,11 @@ module type S = sig
   (** Type of result from calling {!Sexp.parse}. *)
   type ('a, 't) parse_result = ('a, 't) Pre_sexp.parse_result =
     | Done of 't * Parse_pos.t
-    (** [Done (t, parse_pos)] finished parsing
+        (** [Done (t, parse_pos)] finished parsing
         an S-expression.  Current parse position
         is [parse_pos]. *)
     | Cont of Cont_state.t * ('a, 't) parse_fun
-    (** [Cont (cont_state, parse_fun)] met the end of input before completely
+        (** [Cont (cont_state, parse_fun)] met the end of input before completely
         parsing an S-expression.  The user has to call [parse_fun] to
         continue parsing the S-expression in another buffer.  [cont_state]
         is the current parsing state of the continuation.
@@ -231,6 +231,13 @@ module type S = sig
         S-expression. *)
     val of_string : string -> t
 
+    (** [of_string_many] same as {!of_string_many}, but returns a list of annotated
+        S-expressions.
+
+        Similar to {!of_string_many}, on parse failure it raises [Parsexp.Parse_error]
+        rather than a native [Sexplib.Sexp.Parse_error]. *)
+    val of_string_many : string -> t list
+
     (** [of_bigstring bstr] same as {!of_string}, but operates on bigstrings. *)
     val of_bigstring : bigstring -> t
 
@@ -621,7 +628,6 @@ module type S = sig
 
   (** S-expressions annotated with relative source positions and comments *)
   module With_layout : sig
-
     (* relative source positions *)
     type pos = Src_pos.Relative.t =
       { row : int
@@ -658,7 +664,6 @@ module type S = sig
       val t_or_comments : t_or_comment list -> Type.t list
     end
 
-
     module Render : sig
       type asexp
       type 'a t (* monad for position-respecting asexp rendering *)
